@@ -10,31 +10,40 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/dao"
+	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/view"
 	"github.com/derailed/tview"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestLog(t *testing.T) {
-	v := view.NewLog(client.NewGVR("v1/pods"), "fred/p1", "blee", false)
+	opts := dao.LogOptions{
+		Path:      "fred/p1",
+		Container: "blee",
+	}
+	v := view.NewLog(client.NewGVR("v1/pods"), &opts)
 	v.Init(makeContext())
 
-	v.Flush(dao.LogItems{
-		dao.NewLogItemFromString("blee"),
-		dao.NewLogItemFromString("bozo"),
-	}.Lines(false))
+	ii := dao.NewLogItems()
+	ii.Add(dao.NewLogItemFromString("blee"), dao.NewLogItemFromString("bozo"))
+	v.Flush(ii.Lines(false))
 
 	assert.Equal(t, 29, len(v.Logs().GetText(true)))
 }
 
 func BenchmarkLogFlush(b *testing.B) {
-	v := view.NewLog(client.NewGVR("v1/pods"), "fred/p1", "blee", false)
+	opts := dao.LogOptions{
+		Path:      "fred/p1",
+		Container: "blee",
+	}
+	v := view.NewLog(client.NewGVR("v1/pods"), &opts)
 	v.Init(makeContext())
 
-	items := dao.LogItems{
+	items := dao.NewLogItems()
+	items.Add(
 		dao.NewLogItemFromString("blee"),
 		dao.NewLogItemFromString("bozo"),
-	}
+	)
 	b.ReportAllocs()
 	b.ResetTimer()
 	for n := 0; n < b.N; n++ {
@@ -57,14 +66,17 @@ func TestLogAnsi(t *testing.T) {
 }
 
 func TestLogViewSave(t *testing.T) {
-	v := view.NewLog(client.NewGVR("v1/pods"), "fred/p1", "blee", false)
+	opts := dao.LogOptions{
+		Path:      "fred/p1",
+		Container: "blee",
+	}
+	v := view.NewLog(client.NewGVR("v1/pods"), &opts)
 	v.Init(makeContext())
 
 	app := makeApp()
-	v.Flush(dao.LogItems{
-		dao.NewLogItemFromString("blee"),
-		dao.NewLogItemFromString("bozo"),
-	}.Lines(false))
+	ii := dao.NewLogItems()
+	ii.Add(dao.NewLogItemFromString("blee"), dao.NewLogItemFromString("bozo"))
+	v.Flush(ii.Lines(false))
 	config.K9sDumpDir = "/tmp"
 	dir := filepath.Join(config.K9sDumpDir, app.Config.K9s.CurrentCluster)
 	c1, _ := ioutil.ReadDir(dir)
@@ -73,6 +85,30 @@ func TestLogViewSave(t *testing.T) {
 	assert.Equal(t, len(c2), len(c1)+1)
 }
 
+func TestAllContainerKeyBinding(t *testing.T) {
+	uu := map[string]struct {
+		opts *dao.LogOptions
+		e    bool
+	}{
+		"action-present": {
+			opts: &dao.LogOptions{Path: "", DefaultContainer: "container"},
+			e:    true,
+		},
+		"action-missing": {
+			opts: &dao.LogOptions{},
+		},
+	}
+	for k := range uu {
+		u := uu[k]
+		t.Run(k, func(t *testing.T) {
+			v := view.NewLog(client.NewGVR("v1/pods"), u.opts)
+			v.Init(makeContext())
+			_, got := v.Logs().Actions()[ui.KeyA]
+			assert.Equal(t, u.e, got)
+		})
+	}
+}
+
 // ----------------------------------------------------------------------------
 // Helpers...
 
